import crypto from 'crypto';
import { checkIsValidKey } from '../utils/utils.js';
// Class to be used when signing with parsed `crypto.KeyObject` private key
// provided directly in the constructor.
export class NodeCryptoSigningStrategy {
    privateKey;
    constructor(privateKey) {
        this.privateKey = privateKey;
        checkIsValidKey('private', privateKey);
    }
    async sign(data) {
        // For ECDSA P-256 keys the algorithm is implicitly selected as SHA-256.
        return crypto.sign(/*algorithm=*/ undefined, data, this.privateKey);
    }
    async getPublicKey() {
        return crypto.createPublicKey(this.privateKey);
    }
}
